==> com.liferay.layout.content.page.editor.web-2.0.122-sources.jar: META-INF/resources/page_editor/app/actions/index.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

export {default as addFragmentComposition} from './addFragmentComposition';
export {default as addFragmentEntryLinks} from './addFragmentEntryLinks';
export {default as addFragmentEntryLinkComment} from './addFragmentEntryLinkComment';
export {default as addMappedInfoItem} from './addMappedInfoItem';
export {default as deleteFragmentEntryLinkComment} from './deleteFragmentEntryLinkComment';
export {default as editFragmentEntryLinkComment} from './editFragmentEntryLinkComment';
export {default as loadReducer} from './loadReducer';
export {default as switchSidebarPanel} from './switchSidebarPanel';
export {default as switchViewportSize} from './switchViewportSize';
export {default as toggleShowResolvedComments} from './toggleShowResolvedComments';
export {default as unloadReducer} from './unloadReducer';
export {default as updateColSize} from './updateColSize';
export {default as updateEditableValues} from './updateEditableValues';
export {default as updateFragmentEntryLinkContent} from './updateFragmentEntryLinkContent';
export {default as updateLanguageId} from './updateLanguageId';
export {default as updateLayoutData} from './updateLayoutData';
export {default as updateNetwork} from './updateNetwork';

==> com.liferay.layout.content.page.editor.web-3.0.106-sources.jar: META-INF/resources/page_editor/app/actions/index.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

export {default as addFragmentComposition} from './addFragmentComposition';
export {default as addFragmentEntryLinks} from './addFragmentEntryLinks';
export {default as addFragmentEntryLinkComment} from './addFragmentEntryLinkComment';
export {default as addMappingFields} from './addMappingFields';
export {default as deleteFragmentEntryLinkComment} from './deleteFragmentEntryLinkComment';
export {default as editFragmentEntryLinkComment} from './editFragmentEntryLinkComment';
export {default as loadReducer} from './loadReducer';
export {default as switchSidebarPanel} from './switchSidebarPanel';
export {default as switchViewportSize} from './switchViewportSize';
export {default as toggleShowResolvedComments} from './toggleShowResolvedComments';
export {default as unloadReducer} from './unloadReducer';
export {default as updateColSize} from './updateColSize';
export {default as updateEditableValues} from './updateEditableValues';
export {default as updateFragmentEntryLinkContent} from './updateFragmentEntryLinkContent';
export {default as updateLanguageId} from './updateLanguageId';
export {default as updateLayoutData} from './updateLayoutData';
export {default as updateNetwork} from './updateNetwork';
